# 2 - Install option #1 - PIP (package installer for python)

## Install tryton in a virtual environment with PIP

PIP is the "package installer for python", which can run on many different platforms. Most, if not all tryton components are hosted in the ["Python Package Index"](http://pypi.org). 

If you install tryton with PIP, you should use **virtual environments**. Thus you can use multiple versions of tryton, for example one *productive* and one *experimental* setup at the same time. The *experimental* can be used to test booking methods or any other actions you are not familiar with sufficiently.

All your versions will normally talk to their own database, all of these live in one **postgresql database server**.

## Install the tryton client
If you want, you can install the client package into your system:
```
$ cd tryton-[Versionsnummer]
$ sudo python3 setup.py install
```
## Create a database

Make sure postgresql is installed and running:\
`$ sudo apt install postgresql`

This command will launch postgresql at every system boot:\
`$ sudo systemctl start postgresql`

Log in as user "postgres" - kind of super user for postgresql:\
`$ sudo su - postgres`

As user "postgres", do\
```
(postgres) $ createdb -O [name-of-database-owner] [name-new-database]
exit
```

You created a database with name [name-new-database], owned by [name-of-database-owner]. Write down name of database, user and password

## Install tryton-pip

If you previously installed tryton-pip system-wide, you need to uninstall all of tryton. Have a look in /usr/local/lib/python3.8/dist-packages/ and walk through all tryton packages listed with this command:\
`$ pip uninstall trytond_*`

Make sure the packages python3-pip and python3-venv are installed. Then:

#### Create a new virtual environment

```
$ cd [dir-where-your-tryton-environments-shall-live] #  '~/Documents/tryton' might be a nice place
$ python3 -m venv --system-site-packages [name-of-your-environment] # I use tryton-version#-[productive|experimental]
```

#### cd into the environment and activate it.

```
$ cd [name-of-your-environment]
$ . bin/activate
```

#### Upgrade pip itself first

`$ pip install --upgrade pip`

#### Then install Tryton.

If you want to install a certain version, add that version as well. For example:\
`$ pip install trytond==5.4.*` will install trytond version 5.4.X

For the latest version, just use\
`$ pip install trytond`

Trytond needs to connect to a database server and needs the package psycopg2 for that. Installing it also means compiling some sourcecode so it wil be easier to install the precompiled version with\
`$ pip install psycopg2-binary`

Create a trytond.conf in which some variables are specified. The most important one is the database uri. Open the empty trytond.conf and add:\
```
[database]
uri = postgresql://[name-of-database-owner]:[database-password]@localhost:5432/
language = en
```

(You wrote down credentials above, did you?)

If you already have a list of modules, install them: \
 `pip install -r [list-of-modules.txt]`

Else, install your modules:\
 `$ pip install trytond_*` "\*" represents all your modules.

Make sure you are in your environment and still have activated it.

Execute\
`(your-environment) $ trytond-admin -c trytond.conf -d [name-new-database] --all -vv`

Tryton will now populate the database with a basic set of tables and data. At the end you will be asked for a admin-email and password. After that, you are back at the commandline.

To run Tryton start Tryton with\
`(your-environment) $ trytond -c trytond.conf -d [name-new-database]`

You should now be able to connect to Tryton with the desktop-client. Open the client and add [localhost:8000] as host and as database [name-new-database]. You can now move to the "tryton user setup" section.

# Maintenance

## Save database and play back

You need regular backups of your work. Your database saves nearly everything - your modules installed, your setup, your customers, your bookings. So be very careful with it.

### Save database

Make sure postgresql is running.

stop trytond:
```
$ cd [your-virtual-environment]
$ . /bin/activate
$ pg_dump -d [name-of-your-database]-U [name-of-database-owner] > [name-of-your-backup-file].sql
```

In case, you need to

### play back your backup:

stop Tryton Client
```
$ cd [your-virtual-environment]
$ deactivate
$ killall trytond
```

Become (super)user postgres:
```sudo su - postgres ```

delete your database:
```
(postgres) $ dropdb [name-of your-recent-database]
(postgres) $ createdb -O [name-of-database-owner] [name-new-#2-database]
exit
```
As normal user:
```
$ psql -d [name-new-#2-database] -U [user-name] < [name-of-your-backup-file]
$ cd [your-virtual-environment]
$ . bin/activate
(your-environment) $ trytond-admin -c [your trytond.conf] -d [name-new-#2-database] --all -v
```
# basic handling of tryton PIP
## install a module
if running: stop Tryton Client
```
$ killall trytond
$ cd [your-virtual-environment]
$ . bin/activate
```
acutally install your module:\
`(your-environment) $ pip install trytond-[name-of-your-module]`
register module to your database\
`(your-environment) $  trytond-admin -c [your trytond.conf] -d [name-of-your-database] --all -v`
start again trytond:\
`(your-environment) $  trytond -c [your trytond.conf] -d [name-of-your-database] -v`

log into tryton client\
 == administration > modules > modules\
 double-click "activate"\
 perform activation (propeller icon)
#### launch postgres (only once, will than start at system boot)

`$ sudo systemctl start postgresql`
#### activate your pip-environment:
```
$ cd ~/[Name-Umgebung]
$ . bin/activate
```
#### start trytond
With PIP environment activated:\
`(your-environment) $ trytond -c trytond.conf -d [name-of-your-database]`

#### launch tryton client:

If not installed:\
`$ [path-to-tryton-client-package]/tryton-[version]/bin/.tryton`

# version update PIP installation

see 5.1 - version update

