# 4 - Tryton - User-Setup
## log into your account
On the GTK client you need to create a profile with your login credentials - user name and the password you created at setup.

On your browser, use `$ localhost:8000`.\
With a PIP install, you need additional steps to make the browser login possible.
## install your language
### docker
stop tryton:\
`$ sudo docker stop tryton`

load your language:\
`$ sudo docker run --link tryton-postgres:postgres -it tryton/tryton trytond-admin -d tryton --all -l ##`

Instead of "##" type your language code according to DIN639-1 - e.g de,fr,it,es, etc

start tryton again:\
 `$ sudo docker start tryton`
### PIP
With your environment activated:\
`$ trytond-admin -c [your-trytond.conf] -d [your-database] -l ## -vv`

Instead of "##" type your language code according to DIN639-1 - e.g de,fr,it,es... etc.

In GUI, goto:\
== Administration > Localization > Languages\
and double-click "Load translations" for your desired language.
## change language of your interface
log into localhost:8000
#### web client:
select your language at user preferences (your user and company name, top right menu item)
#### GTK client:
Tryton menu / or small white wedge top right menu bar > settings > preferences tab

both:\
== Administration > Users > Users > Preferences\
Quit client and log back.

Make sure that English always is available, so you can switch to follow this guide and follow forum debates.

## Install / update the GTK client
* find out the version of your server with
  * for docker: `$ sudo docker run --rm tryton/tryton trytond --version`
  * for PIP: `$ tryton --version`
* Download the sources at [https://downloads.tryton.org], the first two digits of the version (e.g. 5.4.x have to match)
* For linux, you can find the GTK client in the \*.tar.gz package in the "bin" directory.

To achieve a clean install and make the GUI available in your system's menu, install it:
* find out the version of your server
* Download the sources at https://downloads.tryton.org/, the first two digits of the version (e.g. 5.4.x have to match)
* expand the sources
* cd to the sources directory
* run the command `$ sudo python3 setup.py install `(you may need to use another python version later on)
* if anything runs through, you can launch the client at $ /usr/local/bin/tryton

For a *client update*, carry out the steps above - expand the tar.gz package, run the command `$ sudo python3 setup.py install `. 

## basic config
It is quite important to do first things first. Whenever you create entries which do relate to other categories, you might not be able to correct wrong entries.
## config wizard
First steps are run automatically by a setup wizard.
## modules
Modules can easily be activated. Deactivating and deleting modules at the moment (v 5.4) is still in beta status. So in doubt rather try to start with a minimum set of modules and extend it when you are certain you need another module.

When activating modules, double-click the "mark for activation" buttons. Checking boxes at the beginning of the line does not matter for activation. The propeller icon top right will perform installation of the modules.

Selecting your set of modules is a very individual thing, depending on what your business does. [In tryton docs](https://docs.tryton.org/en/latest/#modules) is quite a comprehensive list of modules, what they do and how to handle them. 

This is a list my modules as an example - for a small company selling goods and services in Germany:

account
account_de_skr03
account_invoice
account_invoice_correction
account_invoice_line_standalone
account_invoice_stock
account_payment
account_product
account_stock_continental
bank
carrier
company
country
currency
ir
party
product
product_price_list
purchase
purchase_request
res
sale
sale_price_list
sale_supply
stock
stock_consignment
stock_supply
## create your table of accounts
This depends on the customs of your country, so it's not possible to be general. My guess is that in most countries you can choose a bottom-up or a top-down approach:

### Top-down approach
This probably leaves you with less trouble, but maybe with a much more account tables than you actually need. But don't be afraid, tryton does a good job to hide the complexity from the user.

 install the relevant module from\
  == Administration > Modules > Modules > double click [your contry's account table] > click propeller icon > perform pending...

Back to\
== Financial > Configuration > Accounts\
you should find your accout table.

[Discussion here.](https://discuss.tryton.org/t/account-chart-to-choose/2858/6)

### Bottom-up approach
Not sure whether this is a good idea in general - lots of trouble ahead.... ): If you only want to use a handful accounts, this may be for you. Be warned...

The "minimal account table", which may be available in your language, is more for simple testing and not very well suited to be expanded to a "real" booking account table.

Make sure you have a template for your country which is structured appropriately and has the right boxes ticked and unticked.

Go to:\
== Financial > Configuration > Accounts > Minimal account table\
and create children to the existing accounts.
## introduce your currency
Also in the case you do not want to do business in foreign currency, you need to set up you home currency in the related menu entry and set the exchange rate to "1" - otherwise certain reporting and statistics features will not work. 

## create parties
In tryton, your business partners are called "parties". First and second name go together into one field "name".

Import from a CSV list:\
== Party > Parties > wedge down icon > import data...  

The data import feature of tryton may not be one of the strongest aspects of the system. It's powerful, but not easy to handle. Most data you normally want to import are living under "Adresses". The company name goes in the field "party", don't get confused with the field "party name" - it means something like "not regularly used delivery address", you will not normally use it.

To find out which data fields you need, you can create an example party, fill all the fields, then export it as CSV. The header line shows where your data go. A dash between words there indicates the corresponding hierarcy in the fields list.

## number sequences
== Administration > Sequences  
Many are created by default, your may especially need to create an "invoice" sequence.

## create a fiscal year
== Financial > Configuration > Fiscal Years > Fiscal Years > blue+  

For the first new fiscal year you create, do not use the "propeller" icon near "Renew Fiscal Year", it works for the next years only. Insert your data, select (or create of necessary) sequences from the "sequences" tab, Don't forget to create booking periods (monthly or quarterly) with buttons at the very bottom of the page.

## create taxes
"Taxes" in this place means VAT (Umsatzsteuer) only.  
== Financial > Configuration > Taxes > Taxes  
Create your specific VAT rates and link them with tax accounts at "invoice accounts"

## create warehouse
If you are dealing with goods (not services), you need to use a warehouse  
== Inventory&Stock > Locations > Locations  

Don't create a new warehouse, use and rename the existing ones to your needs. The default warehouse has an input and an output zone, which may be a little overdone for a small company. [Here is an idea how to simplify that.](https://discuss.tryton.org/t/simplify-warehouse-storage-locations/2840)

## create opening entries / balances
[https://discuss.tryton.org/t/opening-balances/494](https://discuss.tryton.org/t/opening-balances/494)

## create products
In tryton, everything for sale is an "product", a non-material "service" is as well. In June 2020, you cannot csv import products, the interface is too buggy.  

== Product > Products > blue+  

"Variants" is for different colours or slight modifications, you cannot apply different list prices for a variant. So e.g. different sizes of screws cannot be treated as "variants". The identification code of a variant will be added as a suffix to the given item code, meaning:  

article code is "art2122"\
variant code is "blue"\
complete code adds up to "art2122blue"

## set up product categories
Product categories are used to make sure that each sold or purchased item is booked into the right account. At least, you will need to set up different VAT rates, if you have them in your country. The rest depends very much on your account table.

[Related forum discussion](https://discuss.tryton.org/t/product-categories/2930)

## create your custom invoice
== Administration > User Interface > Actions > Reports.  
You'll find a list of default reports there. Double click "invoice" and click the download symbol near "content" and file size. You'll downlod an odt file. All the different categories of invoices (draft, proforma, customer etc) are created from this single template. Edit this file to your needs:

* adjust page size
* insert logos, header, footer etc at the first page

When finished upload your file back at "invoice", you need to click the little cross besides the "upload" logo, this clears the "contents" field and you can upload your file by clicking the magnifyer icon.

Test your custom invoice template before posting your real invoice, you may need several attempts until it works.

## create methods of payment
To mark your sales or purchases as "payed", you need to create payment methods. == financial > configuration > journals > invoice payment methods Here you define which accounts are involved with different payment methods. Examples could be

* customer invoice - giro transfer
* supplier invoice - giro transfer 

# ... to be continued and extended...

Comments please send to wd-p@trolink.de
Have fun! - Cheers, Wolf