version update
==============
In theory, it is possible to jump over several versions, this may work, especially if you're a really experienced user and know how to deal with changes in the database. For the rest of us, it's recommended to go step by step, from 5.4 to 5.6 to 5.8 etc.

If you want to get rid of unwanted modules, this is the time. Do deactivate and remove those in the GUI.
## Back up your database
The best thing to do is to store the database dump into the environment directory.
Also make sure postgresql is running.
```
$ cd [your-virtual-environment]
$ pg_dump -U [name-of-database-owner] d- [name-of-your-recent-database] > [name-of-your-backup-file].sql
```
## Back up your installed packages
Create a list of installs:
```
. bin/activate
$ pip freeze --local > [Installs-[of-today].txt]
```
Remove your previously deactivated (unwanted) modules from this list. Also remove
all the packages except those with 'trytond' in front.
## New virtual environment
Create a new virtual environment and activate it
```
$ python3 -m venv --system-site-packages [path-of-your-new-VirtEnv-directory]
$ cd [path-of-your-new-VirtEnv-directory]
$ . bin/activate
```
Copy both previously created files into the environment, especially externally downloaded modules (*whl files), if available. Edit the [Installs-[of-today].txt] and replace all the versions with the desired version.  
For example:
```
[name-of-trytond-module]==5.4.19
[name-of-trytond-module]==5.6.*
```
(the * means, the most recent 5.6.* version, so the latest will be installed)
Do some pip commands
```
$ pip install --upgrade pip
$ pip install --upgrade -r [Installs-[of-today].txt]
```
## New database
Create a new database in a separate terminal window:
```
$ sudo su - postgres
(postgres) $  createdb -O [name-of-database-owner] [name-new-database-new-version]
(postgres) $  exit
$ psql -d [name-new-database-new-version] -U [name-of-database-owner] < [name-of-your-sql-backup-file]
```
## Prepare for upgrade
Most of the upgrade will be automatically done, but there are sometimes changes which have to made manually. These changes are listed at [https://discuss.tryton.org/c/migration/6](https://discuss.tryton.org/c/migration/6).  
Check for each version which changes have to be made manually.

The changes are most of the time SQL queries and you as a user have to read (very carefully) WHEN to execute them.
As an example the upgrade from 5.8 to 6.0:
As stated in https://discuss.tryton.org/t/migration-from-5-8-to-6-0/3603:
1. add manually a new column BEFORE the upgrade\
2. do the upgrade and fix errors until everything is fine\
3. fix some settings on the invoice table and remove an unneeded table column - **example**:
```
$ psql -d [name-new-database-new-version] -U [name-of-database-owner]
[database-name]=> ALTER TABLE ir_model_field ADD COLUMN "access" BOOLEAN;
[database-name]=> [other_SQL_commands]
[database-name]=> \q
```
Your [name-of-your-new-VirtEnv-directory] should still be active
```
$ trytond-admin -c trytond.conf -d [name-new-database-new-version] --all -v
```
Lots of messages will scroll down the screen, but it should not show any error.

**Warning**:  
Because you have only installed the trytond-modules there is a possiblity that the upgrade fails with a "module ... not found". Use the pip command to install those packages and run the upgrade again.  
After the upgrade runs without error, fix and clean up the database
```
$ psql -d [name-new-database-new-version] -U [name-of-database-owner]
[database-name]=> UPDATE account_invoice_line SET currency = (SELECT currency FROM account_invoice WHERE id = account_invoice_line.invoice);
[database-name]=> UPDATE account_invoice_line SET invoice_type = (SELECT type FROM account_invoice WHERE id = account_invoice_line.invoice) WHERE invoice_type IS NOT NULL;
[database-name]=> UPDATE account_invoice_line SET party = (SELECT party FROM account_invoice WHERE id = account_invoice_line.invoice) WHERE party IS NOT NULL;
[database-name]=> ALTER table ir_sequence_type DROP COLUMN code;
[database-name]=> \q
```
You can run the `trytond-admin` upgrade command another time, but your new version of Tryton should now be up and running.
This is about getting from tryton `x.y.*` to `x.y+2.*` .
